# Generated by Django 2.2.3 on 2019-07-14 07:29

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Photo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=250, verbose_name='Название')),
                ('image', models.ImageField(upload_to='gallery', verbose_name='Изображение')),
                ('captions', models.CharField(blank=True, max_length=250, verbose_name='Подпись')),
                ('create_date', models.DateTimeField(auto_now_add=True, verbose_name='Дата добавления')),
                ('slug', models.SlugField(max_length=255)),
            ],
            options={
                'verbose_name': 'Иллюстрация',
                'verbose_name_plural': 'Иллюстрации',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Gallery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=250, verbose_name='Название')),
                ('captions', models.TextField(blank=True, max_length=250, verbose_name='Описание')),
                ('create_date', models.DateTimeField(auto_now_add=True, verbose_name='Дата добавления')),
                ('slug', models.SlugField(max_length=255)),
                ('images', models.ManyToManyField(to='oms_gallery.Photo', verbose_name='Изображение')),
            ],
            options={
                'verbose_name': 'Галерея',
                'verbose_name_plural': 'Галереи',
                'ordering': ['name'],
            },
        ),
    ]
